@@ -766,7 +766,13 @@ nautilus_gtkhtml_view_finalize (GObject *object)
 	view = NAUTILUS_GTKHTML_VIEW (object);
 
 	gnome_vfs_uri_unref (view->details->base);
-	g_object_unref (G_OBJECT (view->details->view));
+
+	/* We shouldn't really need to call html_document_clear() but
+	   libgtkhtml seems to have a bug with reference counting otherwise. */
+	kill_old_connections (view->details->doc);
+	html_document_clear (view->details->doc);
+	g_object_unref (G_OBJECT (view->details->doc));
+
 #if 0
 	if (view->details->menu) {
 		gtk_widget_unref (view->details->menu);
